@@ -125,7 +125,7 @@ bool InstallWindow::Step6CreateShortcuts()
     // Icon path
     QString fullDataDir(_game->DataPath() +
                         "/usr/palm/applications/" +
-                        _game->ID() + "/");
+                        _game->JsonID() + "/");
     QFile iconFile(fullDataDir + _game->JsonIcon());
     QString saneName =_game->JsonTitle().toLower();
     QString newName(QString(ICONS_PATH) +
@@ -150,7 +150,7 @@ bool InstallWindow::Step6CreateShortcuts()
     exec += QString("\"/opt/preenv/wrapper.sh\" "
                     "\"%1\" "
                     "\"%2\"")
-            .arg(_game->ID())
+            .arg(ValidatedDBusName())
             .arg(binary);
 
     QString desktopEntry  =
@@ -205,7 +205,7 @@ bool InstallWindow::Step5PrepareFiles()
     QString binaryFilename = _game->JsonBinary().section('/', -1, -1);
     QString fullDataDir(_game->DataPath() +
                         "/usr/palm/applications/" +
-                        _game->ID() + "/");
+                        _game->JsonID() + "/");
 
     // Copy binary to BinDir
     QFile bin(fullDataDir + _game->JsonBinary());
@@ -238,8 +238,7 @@ bool InstallWindow::Step5PrepareFiles()
 
     PrintOK();
     Sync();
-    ui->animationLabel->hide();
-    _movie.stop();
+
     return Step6CreateShortcuts();
 }
 
@@ -263,12 +262,12 @@ bool InstallWindow::Step4Unpack()
 
 bool InstallWindow::Step4Finished()
 {
+    ui->animationLabel->hide();
+    _movie.stop();
     disconnect(&_proc2, SIGNAL(finished(int)), this, SLOT(Step4Finished()));
 
     if (_proc2.exitCode() != 0)
     {
-        ui->animationLabel->hide();
-        _movie.stop();
         return Failed(tr("Cannot unpack archive:<br />") +
                       QString::fromLocal8Bit(_proc2.readAllStandardError()));
     }
@@ -360,6 +359,14 @@ bool InstallWindow::Step2Finished()
     if (!_game->ParseJson(result))
         return Failed(tr("Error parsing appinfo.json!"));
 
+    // Check if ID matches
+    QRegExp rx(_game->ID());
+    if (!_game->JsonID().contains(rx))
+        return Failed(tr("Seems to be wrong game or naming error!<br />"
+                         "Ipk ID: %1<br />"
+                         "Expected ID mask: %2")
+                      .arg(_game->JsonID())
+                      .arg(_game->ID()));
 
     PrintOK(_game->JsonTitle() + " " +
             _game->JsonVersion() + tr(" by ") +
@@ -398,7 +405,7 @@ bool InstallWindow::Step1SanityCheck()
 
 QString InstallWindow::ValidatedDBusName()
 {
-    return _game->ID()
+    return _game->JsonID()
             .replace('-', '_')
             .remove(QRegExp("[^.a-zA-Z0-9_]"));
 }
