@@ -150,7 +150,7 @@ void SettingsWindow::downloadsDirButton_clicked()
     QString dirName = QFileDialog::getExistingDirectory(
                       this,
                       tr("Downloads Directory"),
-                      downloadsDirButton->valueText());
+                      "/home/user");
     if (!dirName.isEmpty())
         downloadsDirButton->setValueText(dirName);
 #endif
@@ -163,7 +163,7 @@ void SettingsWindow::savesDirButton_clicked()
     QString dirName = QFileDialog::getExistingDirectory(
                 this,
                 tr("Saves Directory"),
-                savesDirButton->valueText());
+                "/home/user");
     if (!dirName.isEmpty())
         savesDirButton->setValueText(dirName);
 #endif
@@ -175,7 +175,7 @@ void SettingsWindow::binDirButton_clicked()
     QString dirName = QFileDialog::getExistingDirectory(
                       this,
                       tr("Binary Directory"),
-                      binDirButton->valueText());
+                      "/home/user");
     if (!dirName.isEmpty())
         binDirButton->setValueText(dirName);
 #endif
@@ -187,7 +187,7 @@ void SettingsWindow::dataDirButton_clicked()
     QString dirName = QFileDialog::getExistingDirectory(
                       this,
                       tr("Game Data Directory"),
-                      dataDirButton->valueText());
+                      "/home/user");
     if (!dirName.isEmpty())
         dataDirButton->setValueText(dirName);
 #endif
