@@ -210,58 +210,63 @@ p, li { white-space: pre-wrap; }
         <translation>Невозможно скопировать бинарный файл </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="252"/>
+        <location filename="../src/installwindow.cpp" line="251"/>
         <source>Unpack archive (it may take a while)</source>
         <translation>Распаковка архива (может занять немного времени)</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="272"/>
+        <location filename="../src/installwindow.cpp" line="271"/>
         <source>Cannot unpack archive:&lt;br /&gt;</source>
         <translation>Невозможно распаковать архив:&lt;br /&gt;</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="287"/>
+        <location filename="../src/installwindow.cpp" line="286"/>
         <source>Prepare directories</source>
         <translation>Подготовка каталогов</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="295"/>
+        <location filename="../src/installwindow.cpp" line="294"/>
         <source>Main property not found in Json: </source>
         <translation>Поле Main не найдено в appinfo.json: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="316"/>
-        <location filename="../src/installwindow.cpp" line="320"/>
+        <location filename="../src/installwindow.cpp" line="315"/>
+        <location filename="../src/installwindow.cpp" line="319"/>
         <source>Can&apos;t create directory %1</source>
         <translation>Не могу создать каталог %1</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="334"/>
+        <location filename="../src/installwindow.cpp" line="333"/>
         <source>Extracting game info</source>
         <translation>Извлечение информации об игре</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="354"/>
+        <location filename="../src/installwindow.cpp" line="353"/>
         <source>Cannot parse JSON: </source>
         <translation>Ошибка разбора JSON: </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="361"/>
+        <location filename="../src/installwindow.cpp" line="360"/>
         <source>Error parsing appinfo.json!</source>
         <translation>Ошибка парсера JSON!</translation>
     </message>
     <message>
         <location filename="../src/installwindow.cpp" line="365"/>
+        <source>Seems to be wrong game or naming error!&lt;br /&gt;Ipk ID: %1&lt;br /&gt;Expected ID mask: %2</source>
+        <translation>Ошибка в соответствии игры имени!&lt;br /&gt;ID из файла: %1&lt;br /&gt;Ожидаемая маска ID: %2</translation>
+    </message>
+    <message>
+        <location filename="../src/installwindow.cpp" line="372"/>
         <source> by </source>
         <translation> от </translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="378"/>
+        <location filename="../src/installwindow.cpp" line="385"/>
         <source>Checking available space</source>
         <translation>Проверка свободного места</translation>
     </message>
     <message>
-        <location filename="../src/installwindow.cpp" line="389"/>
+        <location filename="../src/installwindow.cpp" line="396"/>
         <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
         <translation>Доступное место в MyDocs каталоге - %1МБ, но игре нужно %2МБ!</translation>
     </message>
